==> butler-blocks-1.1.0.tgz: package/lib/documentLabeler/components/fieldsPanel/fieldsPanelDisplayRow/FieldsPanelDisplayRow.stories.js <==
var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
import { jsx as _jsx } from "react/jsx-runtime";
import { Card } from '@material-ui/core';
import { ButlerColorPalette } from '../../../../common/theme/color';
import { FieldsPanelDisplayRow } from './FieldsPanelDisplayRow';
import { MockDocumentLabelerData } from '../../../MockDocumentLabelerData.stories';
import { MockDocumentLabelerProvider } from '../../../MockDocumentLabelerProvider.stories';
import { LabelingSelectionType } from '../../../state/DocumentLabelerState';
import { FieldType } from '../../../../common/types/DocumentLabelerTypes';
export default {
    component: FieldsPanelDisplayRow,
    title: 'FieldsPanelDisplayRow',
    parameters: {
        fileName: __filename,
    },
    decorators: [
        function (Story) { return (_jsx("div", __assign({ style: { width: '360px' } }, { children: _jsx(Card, { children: _jsx(Story, {}) }) }))); },
    ],
};
var defaultParams = {
    id: 'fieldId',
    name: 'Account Number',
    value: '1048151768',
    type: FieldType.Text,
    color: ButlerColorPalette.primary.main,
};
export var Default = function () { return (_jsx(MockDocumentLabelerProvider, { children: _jsx(FieldsPanelDisplayRow, __assign({}, defaultParams)) })); };
var selectedState = {
    docInfo: MockDocumentLabelerData.documentLabelerData,
    localState: {
        activeField: {
            id: 'fieldId',
            type: FieldType.Text,
        },
        selectionType: LabelingSelectionType.Block,
        rootRef: null,
    },
};
export var Selected = function () { return (_jsx(MockDocumentLabelerProvider, __assign({ internalState: selectedState }, { children: _jsx(FieldsPanelDisplayRow, __assign({}, defaultParams)) }))); };
var longNameParams = __assign(__assign({}, defaultParams), { name: 'Account Nuuuuuuuuuuuuuuuuuuuuuuuuuuuuuuuuuuuuuuuuuuuuuuumber' });
export var LongName = function () { return (_jsx(MockDocumentLabelerProvider, { children: _jsx(FieldsPanelDisplayRow, __assign({}, longNameParams)) })); };
var longValueParams = __assign(__assign({}, defaultParams), { value: '1000000000000000000000000000000000000000000000000000048151768' });
export var LongValue = function () { return (_jsx(MockDocumentLabelerProvider, { children: _jsx(FieldsPanelDisplayRow, __assign({}, longValueParams)) })); };

==> butler-blocks-1.1.2.tgz: package/lib/documentLabeler/components/fieldsPanel/fieldsPanelDisplayRow/FieldsPanelDisplayRow.stories.js <==
var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
import { jsx as _jsx } from "react/jsx-runtime";
import { Card } from '@material-ui/core';
import { ButlerColorPalette } from '../../../../common/theme/color';
import { FieldsPanelDisplayRow } from './FieldsPanelDisplayRow';
import { MockDocumentLabelerData } from '../../../MockDocumentLabelerData.stories';
import { MockDocumentLabelerProvider } from '../../../MockDocumentLabelerProvider.stories';
import { LabelingSelectionType, } from '../../../state/DocumentLabelerState';
import { FieldType } from '../../../../common/types/DocumentLabelerTypes';
export default {
    component: FieldsPanelDisplayRow,
    title: 'FieldsPanelDisplayRow',
    parameters: {
        fileName: __filename,
    },
    decorators: [
        function (Story) { return (_jsx("div", __assign({ style: { width: '360px' } }, { children: _jsx(Card, { children: _jsx(Story, {}) }) }))); },
    ],
};
var defaultParams = {
    id: 'fieldId',
    name: 'Account Number',
    value: '1048151768',
    type: FieldType.Text,
    color: ButlerColorPalette.primary.main,
};
export var Default = function () { return (_jsx(MockDocumentLabelerProvider, { children: _jsx(FieldsPanelDisplayRow, __assign({}, defaultParams)) })); };
var selectedState = {
    docInfo: MockDocumentLabelerData.documentLabelerData,
    localState: {
        activeField: {
            id: 'fieldId',
            type: FieldType.Text,
        },
        selectionType: LabelingSelectionType.Block,
        rootRef: null,
    },
};
export var Selected = function () { return (_jsx(MockDocumentLabelerProvider, __assign({ internalState: selectedState }, { children: _jsx(FieldsPanelDisplayRow, __assign({}, defaultParams)) }))); };
var longNameParams = __assign(__assign({}, defaultParams), { name: 'Account Nuuuuuuuuuuuuuuuuuuuuuuuuuuuuuuuuuuuuuuuuuuuuuuumber' });
export var LongName = function () { return (_jsx(MockDocumentLabelerProvider, { children: _jsx(FieldsPanelDisplayRow, __assign({}, longNameParams)) })); };
var longValueParams = __assign(__assign({}, defaultParams), { value: '1000000000000000000000000000000000000000000000000000048151768' });
export var LongValue = function () { return (_jsx(MockDocumentLabelerProvider, { children: _jsx(FieldsPanelDisplayRow, __assign({}, longValueParams)) })); };
